@@ -22,7 +22,7 @@ def argument_present(arguments, default=False, count=1):
 		return default
 	else: raise ValueError("Invalid usage, arguments must either be a list or string.")
 def arguments_present(arguments, default=False, count=1):
-	if isinstance(arguments, str): return argument_present(argument, default=default, count=count)
+	if isinstance(arguments, str): return argument_present(arguments, default=default, count=count)
 	else:
 		for argument in arguments:
 			if argument_present(argument, default=default, count=count):
@@ -312,15 +312,20 @@ class CLI(object):
 				else: break
 			for i in sys.argv:
 				if i not in ["", lexecutable] and not Files.exists(i) and (len(i) < 1 or (i[0] == "-")):
-					if i not in exceptions and f" {i}: " not in self.modes_str and f" {i}: " not in self.options_str and f" {i} " not in self.modes_str and f" {i} " not in self.options_str:
-						error = f"Argument [{i}] is not a valid mode nor option."
-						if json:
-							response.log(error=error, json=True)
-							sys.exit(1)
-						else: 
-							self.docs(stop=False)
-							sys.tracebacklimit = -1 ; sys.traceback_limit = -1
-							raise UnkownArgumentError(error)
+					try:
+						int(i)
+						integer = True
+					except: integer = False
+					if not integer:
+						if i not in exceptions and f" {i}: " not in self.modes_str and f" {i}: " not in self.options_str and f" {i} " not in self.modes_str and f" {i} " not in self.options_str:
+							error = f"Argument [{i}] is not a valid mode nor option."
+							if json:
+								response.log(error=error, json=True)
+								sys.exit(1)
+							else: 
+								self.docs(stop=False)
+								sys.tracebacklimit = -1 ; sys.traceback_limit = -1
+								raise UnkownArgumentError(error)
 		# defaults.
 		def items(self):
 			return vars(self).items()
@@ -683,7 +688,7 @@ class CLI(object):
 		if o != "": doc += "\nOptions:\n"+o
 		if n != "": doc += "\nNotes:\n"+n
 		doc += c
-		return doc
+		return doc.replace(": : *chapter*", ":").replace("*chapter*", "")
 	def __str_representable__(self, dict, start_indent=4):
 		str = json.dumps(dict, indent=4, ensure_ascii=False)[:-2][2:].replace('    "', '    ').replace('": "', " : ").replace('": ', " : ")
 		s, c, max = "", 0, len(str.split('\n'))
